
.plone-navbar-nav li {
  &:hover > .submenu {
    display: block;
  }
  &.active:after,
  &:hover:after {
    content: "";
    display: block;
    position: absolute;
    bottom: -10px;
    width: 100%;
    z-index: 999;
  }
  .submenu {
    background-color: @plone-link-color;
    display: none;
    list-style: none;
    padding-left: 0;
    padding-bottom: 0;
    position: absolute;
    z-index: 9999;
    a {
      color: white;
      display: block;
      line-height: 20px;
      min-width: 14em;
      padding: 15px 10px 15px 12px;
      position: relative;
      &:hover {
        background-color: #9abdd6;
        text-decoration: none;
      }
      &:before {
        margin-right: 10px;
      }
      .submenu_image {
        float: right;
      }
    }
    li {
      position: relative;
      float: left;
      &:hover ul {
        top: 0;
        left: 100%;
      }
    }
  }
}

@media (max-width: 768px) {
  .plone-navbar-nav li {
    .submenu {
      display: none;
    }
    &:hover > .submenu {
      display: none;
    }
  }
}
