.plone-navbar-nav li:hover > .submenu {
  display: block;
}
.plone-navbar-nav li.active:after,
.plone-navbar-nav li:hover:after {
  content: "";
  display: block;
  position: absolute;
  bottom: -10px;
  width: 100%;
  z-index: 999;
}
.plone-navbar-nav li .submenu {
  background-color: #007bb1;
  display: none;
  list-style: none;
  padding-left: 0;
  padding-bottom: 0;
  position: absolute;
  z-index: 9999;
}
.plone-navbar-nav li .submenu a {
  color: white;
  display: block;
  line-height: 20px;
  min-width: 14em;
  padding: 15px 10px 15px 12px;
  position: relative;
}
.plone-navbar-nav li .submenu a:hover {
  background-color: #9abdd6;
  text-decoration: none;
}
.plone-navbar-nav li .submenu a:before {
  margin-right: 10px;
}
.plone-navbar-nav li .submenu a .submenu_image {
  float: right;
}
.plone-navbar-nav li .submenu li {
  position: relative;
  float: left;
}
.plone-navbar-nav li .submenu li:hover ul {
  top: 0;
  left: 100%;
}
@media (max-width: 768px) {
  .plone-navbar-nav li .submenu {
    display: none;
  }
  .plone-navbar-nav li:hover > .submenu {
    display: none;
  }
}
/*# sourceMappingURL=webcouturier.dropdownmenu-compiled.css.map */